← Back to team overview

yade-dev team mailing list archive

[Branch ~yade-dev/yade/trunk] Rev 2009: (Last ?) renaming of classes linked with "my" contact law. The normal inelasticity is now emphasi...

 

------------------------------------------------------------
revno: 2009
committer: jduriez <jduriez@c1solimara-l>
branch nick: trunk
timestamp: Mon 2010-02-08 11:38:35 +0100
message:
  (Last ?) renaming of classes linked with "my" contact law. The normal inelasticity is now emphasized in the name, because it is what is specific to these classes. NB : this 
  contact law takes also into account a moment transfer.
renamed:
  pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp => pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.cpp
  pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp => pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp
  pkg/dem/Engine/Functor/RockJointLawRelationships.cpp => pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.cpp
  pkg/dem/Engine/Functor/RockJointLawRelationships.hpp => pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp
  pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp => pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp
  pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp => pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp
modified:
  pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp
  pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp
  pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp
  pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp
  pkg/dem/PreProcessor/SimpleShear.cpp
  py/system.py
  pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.cpp
  pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp
  pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.cpp
  pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp
  pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp
  pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp


--
lp:yade
https://code.launchpad.net/~yade-dev/yade/trunk

Your team Yade developers is subscribed to branch lp:yade.
To unsubscribe from this branch go to https://code.launchpad.net/~yade-dev/yade/trunk/+edit-subscription.
=== modified file 'pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp'
--- pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp	2010-02-02 16:20:35 +0000
+++ pkg/common/Engine/PartialEngine/CinemCNCEngine.cpp	2010-02-08 10:38:35 +0000
@@ -179,10 +179,10 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "RockJointLaw" ) 
+				if ( ( *itFirst )->getClassName() == "NormalInelasticityLaw" ) 
 				{
-					if(LOG) cout << "RockJointLaw engine found" << endl;
-					myLdc =  YADE_PTR_CAST<RockJointLaw> ( *itFirst );
+					if(LOG) cout << "NormalInelasticityLaw engine found" << endl;
+					myLdc =  YADE_PTR_CAST<NormalInelasticityLaw> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
 				}
 			}

=== modified file 'pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp'
--- pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp	2010-02-02 16:20:35 +0000
+++ pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp	2010-02-08 10:38:35 +0000
@@ -13,7 +13,7 @@
 #include<yade/core/Body.hpp>
 #include <Wm3Vector3.h>
 #include<yade/lib-base/yadeWm3.hpp>
-#include<yade/pkg-dem/RockJointLaw.hpp>
+#include<yade/pkg-dem/NormalInelasticityLaw.hpp>
 
 /*! \brief To apply a constant normal rigidity shear for a parallelogram box (simple shear)
 
@@ -31,7 +31,7 @@
 class CinemKNCEngine : public PartialEngine
 {
 	private :
-		shared_ptr<RockJointLaw> myLdc;
+		shared_ptr<NormalInelasticityLaw> myLdc;
 		Real	coeff_dech;	// the engine cares about it
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha

=== renamed file 'pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp' => 'pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.cpp'
--- pkg/dem/DataClass/InteractionPhysics/RockJointPhys.cpp	2010-02-02 15:26:07 +0000
+++ pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.cpp	2010-02-08 10:38:35 +0000
@@ -6,10 +6,10 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "RockJointPhys.hpp"
-
-
-RockJointPhys::RockJointPhys()
+#include "NormalInelasticityPhys.hpp"
+
+
+NormalInelasticityPhys::NormalInelasticityPhys()
 {
 	createIndex();
 
@@ -28,7 +28,7 @@
 
 }
 
-void RockJointPhys::SetBreakingState()
+void NormalInelasticityPhys::SetBreakingState()
 {
 	
 	//if (fragile) {
@@ -36,17 +36,17 @@
 	
 }
 
-RockJointPhys::~RockJointPhys()
+NormalInelasticityPhys::~NormalInelasticityPhys()
 {
 }
 
-// void RockJointPhys::postProcessAttributes(bool)
+// void NormalInelasticityPhys::postProcessAttributes(bool)
 // {
 // 
 // }
 
 
-YADE_PLUGIN((RockJointPhys));
+YADE_PLUGIN((NormalInelasticityPhys));
 
 // YADE_REQUIRE_FEATURE(PHYSPAR);
 

=== renamed file 'pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp' => 'pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp'
--- pkg/dem/Engine/Functor/RockJointLawRelationships.cpp	2010-02-02 15:26:07 +0000
+++ pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.cpp	2010-02-08 10:38:35 +0000
@@ -6,9 +6,9 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include"RockJointLawRelationships.hpp"
+#include"Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp"
 #include<yade/pkg-dem/ScGeom.hpp>
-#include<yade/pkg-dem/RockJointPhys.hpp>
+#include<yade/pkg-dem/NormalInelasticityPhys.hpp>
 // #include<yade/pkg-dem/SDECLinkGeometry.hpp> // FIXME - I can't dispatch by SDECLinkGeometry <-> ScGeom !!?
 // #include<yade/pkg-dem/SDECLinkPhysics.hpp> // FIXME
 #include<yade/pkg-dem/CohesiveFrictionalMat.hpp>
@@ -16,7 +16,7 @@
 #include<yade/core/Scene.hpp>
 
 
-RockJointLawRelationships::RockJointLawRelationships()
+Ip2_2xCohFrictMat_NormalInelasticityPhys::Ip2_2xCohFrictMat_NormalInelasticityPhys()
 {
 	betaR = 0.12;
 	setCohesionNow = false;
@@ -37,7 +37,7 @@
 //
 //
 
-void RockJointLawRelationships::go(	  const shared_ptr<Material>& b1 // CohesiveFrictionalMat
+void Ip2_2xCohFrictMat_NormalInelasticityPhys::go(	  const shared_ptr<Material>& b1 // CohesiveFrictionalMat
 					, const shared_ptr<Material>& b2 // CohesiveFrictionalMat
 					, const shared_ptr<Interaction>& interaction)
 {
@@ -58,8 +58,8 @@
 		if(!interaction->interactionPhysics)
 		{
 //std::cerr << " isNew, id1: " << interaction->getId1() << " id2: " << interaction->getId2()  << "\n";
-			interaction->interactionPhysics = shared_ptr<RockJointPhys>(new RockJointPhys());
-			RockJointPhys* contactPhysics = YADE_CAST<RockJointPhys*>(interaction->interactionPhysics.get());
+			interaction->interactionPhysics = shared_ptr<NormalInelasticityPhys>(new NormalInelasticityPhys());
+			NormalInelasticityPhys* contactPhysics = YADE_CAST<NormalInelasticityPhys*>(interaction->interactionPhysics.get());
 
 			Real Ea 	= sdec1->young;
 			Real Eb 	= sdec2->young;
@@ -141,7 +141,7 @@
 		{	
 			// FIXME - are those lines necessary ???? what they are doing in fact ???
 			// ANSWER - they are used when you setCohesionNow (contact isNew not)
-			RockJointPhys* contactPhysics = YADE_CAST<RockJointPhys*>(interaction->interactionPhysics.get());
+			NormalInelasticityPhys* contactPhysics = YADE_CAST<NormalInelasticityPhys*>(interaction->interactionPhysics.get());
 
 			contactPhysics->kn = contactPhysics->initialKn;
 			contactPhysics->ks = contactPhysics->initialKs;
@@ -188,6 +188,6 @@
 	}
 #endif
 };
-YADE_PLUGIN((RockJointLawRelationships));
+YADE_PLUGIN((Ip2_2xCohFrictMat_NormalInelasticityPhys));
 
 // YADE_REQUIRE_FEATURE(PHYSPAR);

=== renamed file 'pkg/dem/Engine/Functor/RockJointLawRelationships.hpp' => 'pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp'
--- pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp	2010-02-02 16:20:35 +0000
+++ pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp	2010-02-08 10:38:35 +0000
@@ -6,10 +6,10 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include "RockJointLaw.hpp"
+#include "NormalInelasticityLaw.hpp"
 #include<yade/pkg-dem/CohesiveFrictionalMat.hpp>
 #include<yade/pkg-dem/ScGeom.hpp>
-#include<yade/pkg-dem/RockJointPhys.hpp>
+#include<yade/pkg-dem/NormalInelasticityPhys.hpp>
 #include<yade/core/Omega.hpp>
 #include<yade/core/Scene.hpp>
 
@@ -19,7 +19,7 @@
 
 
 // <<<<<<< TREE
-RockJointLaw::RockJointLaw() : GlobalEngine()
+NormalInelasticityLaw::NormalInelasticityLaw() : GlobalEngine()
 // =======
 // ContactLaw1::ContactLaw1() : GlobalEngine()
 // >>>>>>> MERGE-SOURCE
@@ -32,7 +32,7 @@
 
 
 
-void RockJointLaw::action(Scene* ncb)
+void NormalInelasticityLaw::action(Scene* ncb)
 {
     shared_ptr<BodyContainer>& bodies = ncb->bodies;
 
@@ -59,7 +59,7 @@
 		State* de1 = Body::byId(id1,ncb)->state.get();
 		State* de2 = Body::byId(id2,ncb)->state.get();
 		ScGeom* currentContactGeometry		= YADE_CAST<ScGeom*>(contact->interactionGeometry.get());
-		RockJointPhys* currentContactPhysics = YADE_CAST<RockJointPhys*> (contact->interactionPhysics.get());
+		NormalInelasticityPhys* currentContactPhysics = YADE_CAST<NormalInelasticityPhys*> (contact->interactionPhysics.get());
 
 		Vector3r& shearForce 			= currentContactPhysics->shearForce;
 
@@ -305,7 +305,7 @@
 
 }
 
-YADE_PLUGIN((RockJointLaw));
+YADE_PLUGIN((NormalInelasticityLaw));
 
 // YADE_REQUIRE_FEATURE(PHYSPAR);
 

=== renamed file 'pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp' => 'pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp'
--- pkg/dem/Engine/GlobalEngine/RockJointLaw.hpp	2010-02-02 14:27:14 +0000
+++ pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.hpp	2010-02-08 10:38:35 +0000
@@ -18,16 +18,16 @@
 This contact Law is inspired by CohesiveFrictionalContactLaw (inspired itselve directly from the work of Plassiard & Belheine, see the corresponding articles in "Annual Report 2006" in http://geo.hmg.inpg.fr/frederic/Discrete_Element_Group_FVD.html for example). It allows so to set moments, cohesion, tension limit and (that's the difference) inelastic unloadings in compression between bodies.
 All that concerned brokenBodies (this flag and the erosionactivated one) and the useless "iter" has been suppressed.
 
-The Relationsships corresponding are RockJointLawRelationships, where the rigidities, the friction angles (with their tan()), and the orientations of the interactions are calculated. No more cohesion and tension limits are computed for all the interactions
+The Relationsships corresponding are Ip2_2xCohFrictMat_NormalInelasticityPhys, where the rigidities, the friction angles (with their tan()), and the orientations of the interactions are calculated. No more cohesion and tension limits are computed for all the interactions
 To use it you should also use :
 - CohesiveFrictionalMat for the bodies, with "isCohesive" = 1 (A verifier ce dernier point)
-- RockJointLawRelationships (=> which involves interactions of "RockJointPhys" type)
+- Ip2_2xCohFrictMat_NormalInelasticityPhys (=> which involves interactions of "NormalInelasticityPhys" type)
 
  */
 
 
 // <<<<<<< TREE
-class RockJointLaw : public GlobalEngine
+class NormalInelasticityLaw : public GlobalEngine
 // =======
 // class ContactLaw1 : public GlobalEngine
 // >>>>>>> MERGE-SOURCE
@@ -39,11 +39,11 @@
 		bool momentRotationLaw;
 		bool momentAlwaysElastic;	// if true the value of the momentum (computed only if momentRotationLaw !!) is not limited by a plastic threshold
 	
-		RockJointLaw();
+		NormalInelasticityLaw();
 		void action(Scene*);
 // <<<<<<< TREE
 	REGISTER_ATTRIBUTES(GlobalEngine,(sdecGroupMask)(momentRotationLaw)(coeff_dech)(momentAlwaysElastic));
-	REGISTER_CLASS_NAME(RockJointLaw);
+	REGISTER_CLASS_NAME(NormalInelasticityLaw);
 	REGISTER_BASE_CLASS_NAME(GlobalEngine);
 // =======
 // 	REGISTER_ATTRIBUTES(GlobalEngine,(sdecGroupMask)(momentRotationLaw)(coeff_dech)(momentAlwaysElastic));
@@ -52,6 +52,6 @@
 // >>>>>>> MERGE-SOURCE
 };
 
-REGISTER_SERIALIZABLE(RockJointLaw);
+REGISTER_SERIALIZABLE(NormalInelasticityLaw);
 
 

=== modified file 'pkg/dem/PreProcessor/SimpleShear.cpp'
--- pkg/dem/PreProcessor/SimpleShear.cpp	2010-02-02 15:26:07 +0000
+++ pkg/dem/PreProcessor/SimpleShear.cpp	2010-02-08 10:38:35 +0000
@@ -16,8 +16,8 @@
 #include <yade/lib-miniWm3/Wm3Math.h>
 
 #include <yade/pkg-dem/CohesiveFrictionalMat.hpp>
-#include <yade/pkg-dem/RockJointLaw.hpp>
-#include <yade/pkg-dem/RockJointLawRelationships.hpp>
+#include <yade/pkg-dem/NormalInelasticityLaw.hpp>
+#include <yade/pkg-dem/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp>
 #include<yade/pkg-dem/GlobalStiffnessTimeStepper.hpp>
 #include <yade/pkg-dem/PositionOrientationRecorder.hpp>
 
@@ -272,7 +272,7 @@
 	interactionGeometryDispatcher->add("Ig2_Box_Sphere_ScGeom");
 
 	shared_ptr<InteractionPhysicsDispatcher> interactionPhysicsDispatcher(new InteractionPhysicsDispatcher);
-	shared_ptr<InteractionPhysicsFunctor> CL1Rel(new RockJointLawRelationships);
+	shared_ptr<InteractionPhysicsFunctor> CL1Rel(new Ip2_2xCohFrictMat_NormalInelasticityPhys);
 	interactionPhysicsDispatcher->add(CL1Rel);
 
 	shared_ptr<BoundDispatcher> boundDispatcher	= shared_ptr<BoundDispatcher>(new BoundDispatcher);
@@ -298,7 +298,7 @@
 	rootBody->engines.push_back(shared_ptr<Engine>(new InsertionSortCollider));
 	rootBody->engines.push_back(interactionGeometryDispatcher);
 	rootBody->engines.push_back(interactionPhysicsDispatcher);
-	rootBody->engines.push_back(shared_ptr<Engine>(new RockJointLaw));
+	rootBody->engines.push_back(shared_ptr<Engine>(new NormalInelasticityLaw));
 	if(gravApplied)
 		rootBody->engines.push_back(gravityCondition);
 	if(shearApplied)

=== modified file 'py/system.py'
--- py/system.py	2010-02-06 16:01:07 +0000
+++ py/system.py	2010-02-08 10:38:35 +0000
@@ -110,6 +110,9 @@
 	'ContactLaw1Interaction':'RockJointPhys', # Tue Feb  2 14:55:34 2010, jduriez@c1solimara-l
 	'CL1Relationships':'RockJointLawRelationships', # Tue Feb  2 14:58:02 2010, jduriez@c1solimara-l
 	'GLDrawCpmPhys':'Gl1_CpmPhys', # Sat Feb  6 14:46:08 2010, vaclav@flux
+	'RockJointLaw':'NormalInelasticityLaw', # Mon Feb  8 11:17:00 2010, jduriez@c1solimara-l
+	'RockJointPhys':'NormalInelasticityPhys', # Mon Feb  8 11:17:35 2010, jduriez@c1solimara-l
+	'RockJointLawRelationships':'Ip2_2xCohFrictMat_NormalInelasticityPhys', # Mon Feb  8 11:17:59 2010, jduriez@c1solimara-l
 	### END_RENAMED_CLASSES_LIST ### (do not delete this line; scripts/rename-class.py uses it
 }
 


Follow ups
--- pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp	2010-02-02 14:27:14 +0000
+++ pkg/common/Engine/PartialEngine/CinemCNCEngine.hpp	2010-02-08 10:38:35 +0000
@@ -13,7 +13,7 @@
 #include<yade/core/Body.hpp>
 #include <Wm3Vector3.h>
 #include<yade/lib-base/yadeWm3.hpp>
-#include<yade/pkg-dem/RockJointLaw.hpp>
+#include<yade/pkg-dem/NormalInelasticityLaw.hpp>
 
 
 /*! \brief To apply a constant normal stress shear for a parallelogram box (simple shear)
@@ -33,8 +33,8 @@
 class CinemCNCEngine : public PartialEngine
 {
 	private :
-		shared_ptr<RockJointLaw> myLdc;
-		Real	coeff_dech;	// in the case of the use of "RockJointLaw" for ex where kn(unload)#kn(load). The engine cares to find the value at the first run
+		shared_ptr<NormalInelasticityLaw> myLdc;
+		Real	coeff_dech;	// in the case of the use of "NormalInelasticityLaw" for ex where kn(unload)#kn(load). The engine cares to find the value at the first run
 		Real	alpha	// angle from the lower plate to the left box (trigo wise), the Engine finds itself its value
 			,dalpha	// the increment over alpha, due to vertical displacement of upper box
 			,gamma	// horizontal displacement done since the launch of the calcul first step

=== modified file 'pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp'
--- pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp	2010-02-02 16:20:35 +0000
+++ pkg/common/Engine/PartialEngine/CinemKNCEngine.cpp	2010-02-08 10:38:35 +0000
@@ -157,11 +157,11 @@
 			vector<shared_ptr<Engine> >::iterator itLast = ncb->engines.end();
 			for ( ;itFirst!=itLast; ++itFirst )
 			{
-				if ( ( *itFirst )->getClassName() == "RockJointLaw" ) 
+				if ( ( *itFirst )->getClassName() == "NormalInelasticityLaw" ) 
 				{
-					myLdc =  YADE_PTR_CAST<RockJointLaw> ( *itFirst );
+					myLdc =  YADE_PTR_CAST<NormalInelasticityLaw> ( *itFirst );
 					coeff_dech = myLdc ->coeff_dech;
-					if(LOG) cout << "RockJointLaw engine found, with coeff_dech = " << coeff_dech << endl;
+					if(LOG) cout << "NormalInelasticityLaw engine found, with coeff_dech = " << coeff_dech << endl;
 				}
 			}
 		}
@@ -188,7 +188,7 @@
 	Real Hcurrent = topbox->state->pos.Y();
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
 // Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de RockJointLaw :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;
 
@@ -188,7 +188,7 @@
 	Real Fdesired = F_0 + KnC * 1.0e9 * Scontact * (Hcurrent-Y0); // The value of the force desired
 
-// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de RockJointLaw :
+// Prise en compte de la difference de rigidite entre charge et decharge dans le cadre de NormalInelasticityLaw :
 	if( F_sup.Y() > Fdesired )	// cas ou l'on va monter la plaq <=> (normalemt) a une decharge
 		stiffness *= coeff_dech;

=== modified file 'pkg/common/Engine/PartialEngine/CinemKNCEngine.hpp'
--- pkg/dem/DataClass/InteractionPhysics/RockJointPhys.hpp	2010-02-02 14:27:14 +0000
+++ pkg/dem/DataClass/InteractionPhysics/NormalInelasticityPhys.hpp	2010-02-08 10:38:35 +0000
@@ -10,12 +10,12 @@
 
 #include<yade/pkg-dem/FrictPhys.hpp>
 
 /*! \brief Interaction for using RockJointLaw
 
 This interaction is similar to CohesiveFrictionalContactInteraction. Among the differences are the unMax, previousun and previousFn (allowing to describe the inelastic unloadings in compression), no more shear and tension Adhesion, no more "fragile", "cohesionBroken" and "cohesionDisablesFriction"
  */
 
-class RockJointPhys : public FrictPhys
+class NormalInelasticityPhys : public FrictPhys
 {
 	public :
 		Real		unMax,		// the maximum value of penetration depth of the history of this interaction
@@ -31,17 +31,17 @@
 		Vector3r	initialPosition1,initialPosition2;
 
 	
-		RockJointPhys();
-		virtual ~RockJointPhys();
+		NormalInelasticityPhys();
+		virtual ~NormalInelasticityPhys();
 		void SetBreakingState ();
 	REGISTER_ATTRIBUTES(FrictPhys,(unMax)(previousun)(previousFn)(initialOrientation1)(initialOrientation2)(orientationToContact1)(orientationToContact2)(currentContactOrientation)(initialContactOrientation)(initialPosition1)(initialPosition2)(forMaxMoment)(kr));
-	REGISTER_CLASS_NAME(RockJointPhys);
+	REGISTER_CLASS_NAME(NormalInelasticityPhys);
 	REGISTER_BASE_CLASS_NAME(FrictPhys);
 
-	REGISTER_CLASS_INDEX(RockJointPhys,FrictPhys);
+	REGISTER_CLASS_INDEX(NormalInelasticityPhys,FrictPhys);
 
 };
 
-REGISTER_SERIALIZABLE(RockJointPhys);
+REGISTER_SERIALIZABLE(NormalInelasticityPhys);
 
 
@@ -10,12 +10,12 @@
 #include<yade/pkg-dem/FrictPhys.hpp>
 
-/*! \brief Interaction for using RockJointLaw
+/*! \brief Interaction for using NormalInelasticityLaw
 
 This interaction is similar to CohesiveFrictionalContactInteraction. Among the differences are the unMax, previousun and previousFn (allowing to describe the inelastic unloadings in compression), no more shear and tension Adhesion, no more "fragile", "cohesionBroken" and "cohesionDisablesFriction"

=== renamed file 'pkg/dem/Engine/Functor/RockJointLawRelationships.cpp' => 'pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.cpp'
--- pkg/dem/Engine/Functor/RockJointLawRelationships.hpp	2010-02-02 15:26:07 +0000
+++ pkg/dem/Engine/Functor/Ip2_2xCohFrictMat_NormalInelasticityPhys.hpp	2010-02-08 10:38:35 +0000
@@ -10,16 +10,16 @@
 
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
 /*! \brief The RelationShips for using RockJointLaw
 
-In these RelationShips all the attributes of the interactions (which are of RockJointPhys type) are computed.
+In these RelationShips all the attributes of the interactions (which are of NormalInelasticityPhys type) are computed.
 WARNING : as in the others Relationships most of the attributes are computed only once : when the interaction is "new"
  */
 
-class RockJointLawRelationships : public InteractionPhysicsFunctor
+class Ip2_2xCohFrictMat_NormalInelasticityPhys : public InteractionPhysicsFunctor
 {
 	public :
-		RockJointLawRelationships();
+		Ip2_2xCohFrictMat_NormalInelasticityPhys();
 
 		virtual void go(	const shared_ptr<Material>& b1,
 					const shared_ptr<Material>& b2,
@@ -35,11 +35,11 @@
 		long iter;//REMOVE THIS
 
 	FUNCTOR2D(CohesiveFrictionalMat,CohesiveFrictionalMat);
-	REGISTER_CLASS_NAME(RockJointLawRelationships);
+	REGISTER_CLASS_NAME(Ip2_2xCohFrictMat_NormalInelasticityPhys);
 	REGISTER_BASE_CLASS_NAME(InteractionPhysicsFunctor);
 	REGISTER_ATTRIBUTES(InteractionPhysicsFunctor,(betaR)(setCohesionNow)(setCohesionOnNewContacts));
 };
 
-REGISTER_SERIALIZABLE(RockJointLawRelationships);
+REGISTER_SERIALIZABLE(Ip2_2xCohFrictMat_NormalInelasticityPhys);
 
 
@@ -10,16 +10,16 @@
 #include<yade/pkg-common/InteractionPhysicsFunctor.hpp>
 
-/*! \brief The RelationShips for using RockJointLaw
+/*! \brief The RelationShips for using NormalInelasticityLaw
 

=== renamed file 'pkg/dem/Engine/GlobalEngine/RockJointLaw.cpp' => 'pkg/dem/Engine/GlobalEngine/NormalInelasticityLaw.cpp'